@@ -8,6 +8,7 @@ import android.net.Uri;
 import android.os.Build;
 import android.os.Environment;
 import android.support.annotation.NonNull;
+import android.support.annotation.WorkerThread;
 import android.support.v4.content.ContextCompat;
 import android.support.v4.content.LocalBroadcastManager;
 import android.text.TextUtils;
@@ -52,7 +53,6 @@ public class Medialibrary {
     public static final String VLC_MEDIA_DB_NAME = "/vlc_media.db";
     public static final String THUMBS_FOLDER_NAME = "/thumbs";
 
-    private Context mContext;
 
     private long mInstanceID;
     private volatile boolean mIsInitiated = false;
@@ -68,6 +68,7 @@ public class Medialibrary {
     private final List<EntryPointsEventsCb> entryPointsEventsCbList = new ArrayList<>();
 
     private static Medialibrary sInstance;
+    private static Context sContext;
 
     static {
         LibVLC.loadLibraries();
@@ -75,10 +76,14 @@ public class Medialibrary {
         System.loadLibrary("mla");
     }
 
+    public static Context getContext() {
+        return sContext;
+    }
+
     public boolean init(Context context) {
         if (context == null)
             return false;
-        mContext = context;
+        sContext = context;
         File extFilesDir = context.getExternalFilesDir(null);
         File dbDirectory = context.getDir("db", Context.MODE_PRIVATE);
         if (extFilesDir == null || !extFilesDir.exists())
@@ -143,18 +148,22 @@ public class Medialibrary {
         return sInstance;
     }
 
+    @WorkerThread
     public MediaWrapper[] getVideos() {
         return mIsInitiated ? nativeGetVideos() : new MediaWrapper[0];
     }
 
+    @WorkerThread
     public MediaWrapper[] getRecentVideos() {
         return mIsInitiated ? nativeGetRecentVideos() : new MediaWrapper[0];
     }
 
+    @WorkerThread
     public MediaWrapper[] getAudio() {
         return mIsInitiated ? nativeGetAudio() : new MediaWrapper[0];
     }
 
+    @WorkerThread
     public MediaWrapper[] getRecentAudio() {
         return mIsInitiated ? nativeGetRecentAudio() : new MediaWrapper[0];
     }
@@ -167,14 +176,17 @@ public class Medialibrary {
         return mIsInitiated ? nativeGetAudioCount() : 0;
     }
 
+    @WorkerThread
     public Album[] getAlbums() {
         return mIsInitiated ? nativeGetAlbums() : new Album[0];
     }
 
+    @WorkerThread
     public Album getAlbum(long albumId) {
         return mIsInitiated ? nativeGetAlbum(albumId) : null;
     }
 
+    @WorkerThread
     public Artist[] getArtists() {
         return mIsInitiated ? nativeGetArtists() : new Artist[0];
     }
@@ -183,6 +195,7 @@ public class Medialibrary {
         return mIsInitiated ? nativeGetArtist(artistId) : null;
     }
 
+    @WorkerThread
     public Genre[] getGenres() {
         return mIsInitiated ? nativeGetGenres() : new Genre[0];
     }
@@ -191,6 +204,7 @@ public class Medialibrary {
         return mIsInitiated ? nativeGetGenre(genreId) : null;
     }
 
+    @WorkerThread
     public Playlist[] getPlaylists() {
         return mIsInitiated ? nativeGetPlaylists() : new Playlist[0];
     }
@@ -228,10 +242,12 @@ public class Medialibrary {
             nativeForceParserRetry();
     }
 
+    @WorkerThread
     public MediaWrapper[] lastMediaPlayed() {
         return mIsInitiated ? nativeLastMediaPlayed() : EMPTY_COLLECTION;
     }
 
+    @WorkerThread
     public HistoryItem[] lastStreamsPlayed() {
         return mIsInitiated ? nativeLastStreamsPlayed() : new HistoryItem[0];
     }
@@ -386,7 +402,7 @@ public class Medialibrary {
 
     @SuppressWarnings("unused")
     public void onBackgroundTasksIdleChanged(boolean isIdle) {
-        LocalBroadcastManager.getInstance(mContext).sendBroadcast(new Intent(ACTION_IDLE).putExtra(STATE_IDLE, isIdle));
+        LocalBroadcastManager.getInstance(sContext).sendBroadcast(new Intent(ACTION_IDLE).putExtra(STATE_IDLE, isIdle));
         mIsWorking = !isIdle;
     }
 
