@@ -168,23 +168,25 @@ public class MainTvActivity extends BaseTvActivity implements OnItemViewSelected
         /*
          * skip browser and show directly Audio Player if a song is playing
          */
-        if (mMediaLibrary.isInitiated() && (mRowsAdapter == null || mRowsAdapter.size() == 0) && Permissions.canReadStorage())
+        if ((mRowsAdapter == null || mRowsAdapter.size() == 0) && Permissions.canReadStorage())
             update();
         else {
             updateBrowsers();
             updateNowPlayingCard();
-            VLCApplication.runBackground(new Runnable() {
-                @Override
-                public void run() {
-                    final MediaWrapper[] history = VLCApplication.getMLInstance().lastMediaPlayed();
-                    mHandler.post(new Runnable() {
-                        @Override
-                        public void run() {
-                            updateHistory(history);
-                        }
-                    });
-                }
-            });
+            if (mMediaLibrary.isInitiated()) {
+                VLCApplication.runBackground(new Runnable() {
+                    @Override
+                    public void run() {
+                        final MediaWrapper[] history = mMediaLibrary.lastMediaPlayed();
+                        mHandler.post(new Runnable() {
+                            @Override
+                            public void run() {
+                                updateHistory(history);
+                            }
+                        });
+                    }
+                });
+            }
         }
     }
 
